@@ -1,8 +1,8 @@
 /*
-** Astrolog (Version 5.30) File: astrolog.c
+** Astrolog (Version 5.40) File: astrolog.c
 **
 ** IMPORTANT NOTICE: The graphics database and chart display routines
-** used in this program are Copyright (C) 1991-1996 by Walter D. Pullen
+** used in this program are Copyright (C) 1991-1998 by Walter D. Pullen
 ** (Astara@msn.com, http://www.magitech.com/~cruiser1/astrolog.htm).
 ** Permission is granted to freely use and distribute these routines
 ** provided one doesn't sell, restrict, or profit from them in any way.
@@ -32,7 +32,7 @@
 ** Initial programming 8/28,30, 9/10,13,16,20,23, 10/3,6,7, 11/7,10,21/1991.
 ** X Window graphics initially programmed 10/23-29/1991.
 ** PostScript graphics initially programmed 11/29-30/1992.
-** Last code change made 9/22/1996.
+** Last code change made 12/20/1998.
 */
 
 #include "astrolog.h"
@@ -120,7 +120,7 @@ void Action()
     is.S = stdout;
 
   if (FPrintTables())    /* Print out any generic tables specified.        */
-    return;              /* If nothing else to do, we can exit right away. */
+    goto LDone;          /* If nothing else to do, we can exit right away. */
   if (is.fMult) {
     PrintL2();
     is.fMult = fFalse;
@@ -165,6 +165,7 @@ void Action()
   if (us.fWriteFile)        /* If -o switch in effect, then write */
     FOutputData();          /* the chart information to a file.   */
 
+LDone:
   if (is.S != stdout) /* If we were internally directing chart display to a */
     fclose(is.S);     /* file as with the -os switch, close it here.        */
 
@@ -562,6 +563,8 @@ char **argv;
       }
       ruler1[i] = j;
       ruler2[i] = k;
+      if (FBetween(i, 1, oMain) && j != 0)
+        rules[j] = i;
     } else
       exalt[i] = j;
     darg += 3 - (ch1 == '0');
@@ -991,6 +994,7 @@ char **argv;
           return fFalse;
         }
         us.nEphemYears = i;
+        argc--; argv++;
       }
       break;
 
@@ -1196,6 +1200,32 @@ char **argv;
         DD = i;
         argc--; argv++;
         break;
+      } else if (ch1 == 'm') {
+        if (argc <= 1) {
+          ErrorArgc("zm");
+          return fFalse;
+        }
+        i = NParseSz(argv[1], pmMon);
+        if (!FValidMon(i)) {
+          ErrorValN("zm", i);
+          return fFalse;
+        }
+        MM = i;
+        argc--; argv++;
+        break;
+      } else if (ch1 == 'y') {
+        if (argc <= 1) {
+          ErrorArgc("zy");
+          return fFalse;
+        }
+        i = NParseSz(argv[1], pmYea);
+        if (!FValidYea(i)) {
+          ErrorValN("zy", i);
+          return fFalse;
+        }
+        YY = i;
+        argc--; argv++;
+        break;
       } else if (ch1 == 'i') {
         if (argc <= 2) {
           ErrorArgc("zi");
@@ -1591,6 +1621,14 @@ char **argv;
       SwitchF(us.fGeodetic);
       break;
 
+    case 'J':
+      SwitchF(us.fVedic);
+      break;
+
+    case '9':
+      SwitchF(us.fNavamsa);
+      break;
+
     case 'F':
       if (argc <= 3) {
         ErrorArgc("F");
@@ -1665,9 +1703,12 @@ char **argv;
         us.fSolarArc = (ch2 == '0');
       } else
         us.nRel = rcSynastry;
+      ci = ciCore;
+      ciCore = ciTwin;
       if (!FInputData(argv[2]))
         return fFalse;
       ciTwin = ciCore;
+      ciCore = ci;
       if (!FInputData(argv[1]))
         return fFalse;
       if (i > 2) {
