@@ -1,8 +1,8 @@
 /*
-** Astrolog (Version 5.30) File: astrolog.h
+** Astrolog (Version 5.40) File: astrolog.h
 **
 ** IMPORTANT NOTICE: The graphics database and chart display routines
-** used in this program are Copyright (C) 1991-1996 by Walter D. Pullen
+** used in this program are Copyright (C) 1991-1998 by Walter D. Pullen
 ** (Astara@msn.com, http://www.magitech.com/~cruiser1/astrolog.htm).
 ** Permission is granted to freely use and distribute these routines
 ** provided one doesn't sell, restrict, or profit from them in any way.
@@ -32,7 +32,7 @@
 ** Initial programming 8/28,30, 9/10,13,16,20,23, 10/3,6,7, 11/7,10,21/1991.
 ** X Window graphics initially programmed 10/23-29/1991.
 ** PostScript graphics initially programmed 11/29-30/1992.
-** Last code change made 9/22/1996.
+** Last code change made 12/20/1998.
 */
 
 /*
@@ -82,7 +82,7 @@
 #define ENVIRON /* Comment out this #define if your system doesn't have  */
                 /* environment variables or can't compile calls to them. */
 
-#define ATOF /* Comment out this #define if you have a system in which  */
+/*#define ATOF /* Comment out this #define if you have a system in which  */
              /* 'atof' and related functions aren't defined in stdio.h, */
              /* such as most PC's, Linux, VMS compilers, and NeXT's.    */
 
@@ -476,8 +476,8 @@
 #define fTrue  TRUE
 
 #define szAppNameCore "Astrolog"
-#define szVersionCore "5.30"
-#define szDateCore    "September 1996"
+#define szVersionCore "5.40"
+#define szDateCore    "December, 1998"
 #define szAddressCore \
   "Astara@msn.com - http://www.magitech.com/~cruiser1/astrolog.htm"
 #define szNowCore     "now"
@@ -524,7 +524,7 @@
 #define objMax     (cObj+1)
 #define cAspect    18
 #define cAspectInt 11
-#define cSystem    14
+#define cSystem    15
 #define cCnstl     88
 #define cZone      69
 #define cSector    36
@@ -811,6 +811,7 @@
 #define SFromZ(r) (((int)(r))/30+1)
 #define RFromD(r) ((r)/rDegRad)
 #define DFromR(r) ((r)*rDegRad)
+#define GFromO(o) ((rDegMax - planet[o])/10.0)
 #define RAbs(r) fabs(r)
 #define RFloor(r) floor(r)
 #define NFloor(r) ((int)RFloor(r))
@@ -1005,7 +1006,7 @@
 /* Determine (co)sin factors based on zodiac angle and chart orientation. */
 #define PX(A) RCosD(A)
 #define PY(A) RSinD(A)
-#define PZ(A) Mod(rDegHalf-(A)+asc)
+#define PZ(A) PlaceInX(A)
 
 /* Compute Mollewide projection in pixel scale given latitude. */
 #define NMollewide(y) \
@@ -1131,9 +1132,11 @@ typedef struct _UserSettings {
   _bool fUranian;     /* -u */
   _bool fProgress;    /* Are we doing a -p progressed chart?           */
   _bool fInterpret;   /* Is -I interpretation switch in effect?        */
-  _bool fFlip;        /* -f */
   _bool fDecan;       /* -3 */
+  _bool fFlip;        /* -f */
   _bool fGeodetic;    /* -G */
+  _bool fVedic;       /* -J */
+  _bool fNavamsa;     /* -9 */
   _bool fPlacalc;     /* -b */
   _bool fWriteFile;   /* -o */
   _bool fAnsiColor;   /* -k */
@@ -1293,6 +1296,7 @@ typedef struct _GraphicsInternal {
   char *szFileOut;      /* Current name of bitmap file (-Xo).         */
   FILE *file;           /* Actual file handle writing graphics to.    */
   int yBand;            /* Vertical offset to current bitmap band.    */
+  real rAsc;            /* Degree to be at left edge in wheel charts. */
   _bool fFile;          /* Are we making a graphics file.             */
   int nScale;           /* Scale ratio, i.e. percentage / 100.        */
   int nScaleT;          /* Relative scale to draw chart text at.      */
