@@ -1,8 +1,8 @@
 /*
-** Astrolog (Version 5.30) File: calc.c
+** Astrolog (Version 5.40) File: calc.c
 **
 ** IMPORTANT NOTICE: The graphics database and chart display routines
-** used in this program are Copyright (C) 1991-1996 by Walter D. Pullen
+** used in this program are Copyright (C) 1991-1998 by Walter D. Pullen
 ** (Astara@msn.com, http://www.magitech.com/~cruiser1/astrolog.htm).
 ** Permission is granted to freely use and distribute these routines
 ** provided one doesn't sell, restrict, or profit from them in any way.
@@ -32,7 +32,7 @@
 ** Initial programming 8/28,30, 9/10,13,16,20,23, 10/3,6,7, 11/7,10,21/1991.
 ** X Window graphics initially programmed 10/23-29/1991.
 ** PostScript graphics initially programmed 11/29-30/1992.
-** Last code change made 9/22/1996.
+** Last code change made 12/20/1998.
 */
 
 #include "astrolog.h"
@@ -140,7 +140,19 @@ void HouseWhole()
   int i;
 
   for (i = 1; i <= cSign; i++)
-    chouse[i] = Mod((SFromZ(is.Asc)-1)*30+ZFromS(i));
+    chouse[i] = Mod((real)((SFromZ(is.Asc)-1)*30) + ZFromS(i));
+}
+
+
+/* The "Vedic" house system is like the Equal system except each house      */
+/* starts 15 degrees earlier. The Asc falls in the middle of the 1st house. */
+
+void HouseVedic()
+{
+  int i;
+
+  for (i = 1; i <= cSign; i++)
+    chouse[i] = Mod(is.Asc - 15.0 + ZFromS(i));
 }
 
 
@@ -167,9 +179,14 @@ int housesystem;
     sprintf(sz,
       "The %s system of houses is not defined at extreme latitudes.",
       szSystem[housesystem]);
-    PrintError(sz);
-    Terminate(tcFatal);
+    PrintWarning(sz);
+    AA = RSgn2(AA)*RFromD(rDegQuad-rAxis);
   }
+
+  /* Flip the Ascendant if it falls in the wrong half of the zodiac. */
+  if (MinDifference(is.MC, is.Asc) < 0.0)
+    is.Asc = Mod(is.Asc + rDegHalf);
+
   switch (housesystem) {
   case  1: HouseKoch();           break;
   case  2: HouseEqual();          break;
@@ -183,7 +200,8 @@ int housesystem;
   case 10: HouseEqualMidheaven(); break;
   case 11: HousePorphyryNeo();    break;
   case 12: HouseWhole();          break;
-  case 13: HouseNull();           break;
+  case 13: HouseVedic();          break;
+  case 14: HouseNull();           break;
   default: HousePlacidus();
   }
 }
@@ -287,6 +305,23 @@ real deg;
 }
 
 
+/* Given a zodiac degree, transform it into its Navamsa position, where   */
+/* each sign is divided into ninths, which determines the number of signs */
+/* after a base element sign to use. Degrees within signs are unaffected. */
+
+real Navamsa(deg)
+real deg;
+{
+  int sign, sign2;
+  real unit;
+
+  sign = SFromZ(deg);
+  unit = deg - ZFromS(sign);
+  sign2 = Mod12(((sign-1 & 3)^(2*(sign-1 & 1)))*3+(int)(unit*0.3)+1);
+  return ZFromS(sign2)+unit;
+}
+
+
 /* Transform spherical to rectangular coordinates in x, y, z. */
 
 void SphToRec(r, azi, alt, rx, ry, rz)
@@ -433,7 +468,8 @@ bool fDate;
     /* Calculate position of Part of Fortune. */
 
     j = planet[oMoo]-planet[oSun];
-    if (us.nArabicNight < 0)
+    if (us.nArabicNight < 0 ||
+      (us.nArabicNight == 0 && HousePlaceIn(planet[oSun]) < sLib))
       neg(j);
     j = RAbs(j) < rDegQuad ? j : j - RSgn(j)*rDegMax;
     planet[oFor] = Mod(j+is.Asc);
@@ -525,6 +561,14 @@ bool fDate;
     ComputeInHouses();
   }
 
+  /* If -9 navamsa chart switch in effect, edit positions accordingly. */
+
+  if (us.fNavamsa) {
+    for (i = 0; i <= cObj; i++)
+      planet[i] = Navamsa(planet[i]);
+    ComputeInHouses();
+  }
+
   ciCore = ci;
   return is.T;
 }
