@@ -1,8 +1,8 @@
 /*
-** Astrolog (Version 5.30) File: charts0.c
+** Astrolog (Version 5.40) File: charts0.c
 **
 ** IMPORTANT NOTICE: The graphics database and chart display routines
-** used in this program are Copyright (C) 1991-1996 by Walter D. Pullen
+** used in this program are Copyright (C) 1991-1998 by Walter D. Pullen
 ** (Astara@msn.com, http://www.magitech.com/~cruiser1/astrolog.htm).
 ** Permission is granted to freely use and distribute these routines
 ** provided one doesn't sell, restrict, or profit from them in any way.
@@ -32,7 +32,7 @@
 ** Initial programming 8/28,30, 9/10,13,16,20,23, 10/3,6,7, 11/7,10,21/1991.
 ** X Window graphics initially programmed 10/23-29/1991.
 ** PostScript graphics initially programmed 11/29-30/1992.
-** Last code change made 9/22/1996.
+** Last code change made 12/20/1998.
 */
 
 #include "astrolog.h"
@@ -301,6 +301,8 @@ void DisplaySwitches()
   PrintS(" _zl <long> <lat>: Change the default longitude & latitude.");
   PrintS(" _zt <time>: Set only the time of current chart.");
   PrintS(" _zd <date>: Set only the day of current chart.");
+  PrintS(" _zm <month>: Set only the month of current chart.");
+  PrintS(" _zy <year>: Set only the year of current chart.");
   PrintS(" _zi <name> <place>: Set name and place strings of current chart.");
   PrintS(" _q <month> <date> <year> <time>: Compute chart with defaults.");
   PrintS(" _qd <month> <date> <year>: Compute chart for noon on date.");
@@ -341,7 +343,7 @@ void DisplaySwitches()
   PrintS("     (0 = Placidus, 1 = Koch, 2 = Equal, 3 = Campanus,");
   PrintS("     4 = Meridian, 5 = Regiomontanus, 6 = Porphyry, 7 = Morinus,");
   PrintS("     8 = Topocentric, 9 = Alcabitius, 10 = Equal (MC),");
-  PrintS("     11 = Neo-Porphyry, 12 = Whole, 13 = None.)");
+  PrintS("     11 = Neo-Porphyry, 12 = Whole, 13 = Vedic, 14 = None.)");
   PrintS(" _s [..]: Compute a sidereal instead of the normal tropical chart.");
   PrintS(" _sr: Compute right ascension locations relative to equator.");
   PrintS(
@@ -359,6 +361,8 @@ void DisplaySwitches()
   PrintS(" _3: Display objects in their zodiac decan positions.");
   PrintS(" _f: Display houses as sign positions (flip them).");
   PrintS(" _G: Compute houses based on geographic location only.");
+  PrintS(" _J: Display wheel charts in Vedic format.");
+  PrintS(" _9: Display objects in their zodiac navamsa positions.");
   PrintS(" _F <objnum> <sign> <deg>: Force object's position to be value.");
   PrintS(" _+ [<days>]: Cast chart for specified no. of days in the future.");
   PrintS(" _- [<days>]: Cast chart for specified no. of days in the past.");
@@ -606,11 +610,13 @@ void PrintSigns()
   int i;
 
   sprintf(sz, "%s signs and houses:\n", szAppName); PrintSz(sz);
-  PrintSz("Sign        English name      House Traditional name\n\n");
+  PrintSz("Sign        English name      House Traditional name");
+  PrintTab(' ', 19); PrintSz("Ruler\n\n");
   for (i = 1; i <= cSign; i++) {
     AnsiColor(kSignA(i));
-    sprintf(sz, "%-12sthe %-14s%2d%s  House of %s\n",
-      szSignName[i], szSignEnglish[i], i, szSuffix[i], szHouseTradition[i]);
+    sprintf(sz, "%-12sthe %-14s%2d%s  House of %-24s  %s\n",
+    szSignName[i], szSignEnglish[i], i, szSuffix[i], szHouseTradition[i],
+    szObjName[rules[i]]);
     PrintSz(sz);
   }
   AnsiColor(kDefault);
@@ -983,8 +989,9 @@ void DisplayKeysX()
   PrintS(" Press 'R', 'C', 'u', 'U' to toggle restriction status of minor");
   PrintS("       objects, minor house cusps, uranian planets, and stars.");
   PrintS(" Press 'c' to toggle relationship comparison chart mode.");
-  PrintS(" Press 's', 'h', 'f', 'g' to toggle status of sidereal zodiac,");
-  PrintS("       heliocentric charts, domal charts, and decan charts.");
+  PrintS(" Press 's', 'h', 'f', 'g', 'z', 'y' to toggle status of sidereal");
+  PrintS("       zodiac, heliocentric charts, domal charts, decan charts,");
+  PrintS("       vedic format wheel charts, and navamsa charts.");
   PrintS(" Press 'O' and 'o' to recall/store a previous chart from memory.");
 #ifdef X11
   PrintS(" Press 'B' to dump current window contents to root background.");
