@@ -1,8 +1,8 @@
 /*
-** Astrolog (Version 5.30) File: charts1.c
+** Astrolog (Version 5.40) File: charts1.c
 **
 ** IMPORTANT NOTICE: The graphics database and chart display routines
-** used in this program are Copyright (C) 1991-1996 by Walter D. Pullen
+** used in this program are Copyright (C) 1991-1998 by Walter D. Pullen
 ** (Astara@msn.com, http://www.magitech.com/~cruiser1/astrolog.htm).
 ** Permission is granted to freely use and distribute these routines
 ** provided one doesn't sell, restrict, or profit from them in any way.
@@ -32,7 +32,7 @@
 ** Initial programming 8/28,30, 9/10,13,16,20,23, 10/3,6,7, 11/7,10,21/1991.
 ** X Window graphics initially programmed 10/23-29/1991.
 ** PostScript graphics initially programmed 11/29-30/1992.
-** Last code change made 9/22/1996.
+** Last code change made 12/20/1998.
 */
 
 #include "astrolog.h"
@@ -434,13 +434,22 @@ void PrintHouse(i, left)
 int i, left;
 {
   char sz[cchSzDef];
+  real r;
+  int j;
 
+  if (us.fVedic) {
+    j = Mod12(12-i);
+    r = ZFromS(j);
+  } else {
+    j = i;
+    r = chouse[i];
+  }
   if (!left)
-    PrintZodiac(chouse[i]);
-  AnsiColor(kSignA(i));
-  sprintf(sz, "<%d>", i); PrintSz(sz);
+    PrintZodiac(r);
+  AnsiColor(kSignA(j));
+  sprintf(sz, "<%d>", j); PrintSz(sz);
   if (left)
-    PrintZodiac(chouse[i]);
+    PrintZodiac(r);
   else
     AnsiColor(kDefault);
 }
@@ -555,7 +564,8 @@ void ChartWheel()
     /* Try to put object in its proper house. If no room, */
     /* then overflow over to the next succeeding house.   */
 
-    for (j = inhouse[i]-1; j < cSign; j = j < cSign ? (j+1)%cSign : j) {
+    for (j = (us.fVedic ? Mod12(11-SFromZ(planet[i])) : inhouse[i])-1;
+      j < cSign; j = j < cSign ? (j+1)%cSign : j) {
 
       /* Now try to find the proper place in the house to put the object. */
       /* This is in sorted order, although a check is made for 0 Aries.   */
@@ -582,9 +592,16 @@ void ChartWheel()
     }
   }
 
-  /* Now, if this is really the -w switch and not -w0, then reverse the */
-  /* order of objects in western houses for more intuitive reading.     */
+  /* Now, if this is really the -w switch and not -w0, then reverse the  */
+  /* order of objects in western houses for more intuitive reading. Also */
+  /* reverse the order of everything in the reverse order Vedic wheels.  */
 
+  if (us.fVedic)
+    for (i = 0; i < cSign; i++)
+      for (j = 0; j < us.nWheelRows/2; j++) {
+        k = us.nWheelRows-1-j;
+        l = wheel[i][j]; wheel[i][j] = wheel[i][k]; wheel[i][k] = l;
+      }
   if (!us.fWheelReverse)
     for (i = 3; i < 9; i++)
       for (j = 0; j < us.nWheelRows/2; j++) {
@@ -595,8 +612,8 @@ void ChartWheel()
   /* Here we actually print the wheel and the objects in it. */
 
   PrintCh(chNW); PrintTab(chH, WHEELCOLS-8); PrintHouse(11, fTrue);
-  PrintTab(chH, WHEELCOLS-11); PrintHouse(10, fTrue);
-  PrintTab(chH, WHEELCOLS-10); PrintHouse(9, fTrue);
+  PrintTab(chH, WHEELCOLS-11+us.fVedic); PrintHouse(10, fTrue);
+  PrintTab(chH, WHEELCOLS-10+us.fVedic); PrintHouse(9, fTrue);
   PrintTab(chH, wheelcols-4); PrintCh(chNE); PrintL();
   for (i = 0; i < us.nWheelRows; i++) {
     for (j = 10; j >= 7; j--) {
@@ -614,7 +631,7 @@ void ChartWheel()
     PrintCh(chV); PrintWheelSlot(wheel[6][i]);
     PrintCh(chV); PrintL();
   }
-  PrintHouse(1, fTrue); PrintTab(chH, WHEELCOLS-10);
+  PrintHouse(1, fTrue); PrintTab(chH, WHEELCOLS-10-us.fVedic);
   PrintCh(chJW); PrintWheelCenter(us.nWheelRows); PrintCh(chJE);
   PrintTab(chH, WHEELCOLS-10); PrintHouse(7, fFalse); PrintL();
   for (i = 0; i < us.nWheelRows; i++) {
@@ -623,7 +640,7 @@ void ChartWheel()
     PrintCh(chV); PrintWheelSlot(wheel[5][i]);
     PrintCh(chV); PrintL();
   }
-  PrintHouse(2, fTrue); PrintTab(chH, WHEELCOLS-10);
+  PrintHouse(2, fTrue); PrintTab(chH, WHEELCOLS-10-us.fVedic);
   PrintCh(chC); PrintTab(chH, wheelcols-1); PrintCh(chJS);
   PrintTab(chH, wheelcols-1); PrintCh(chC);
   PrintTab(chH, WHEELCOLS-10); PrintHouse(6, fFalse); PrintL();
@@ -1034,7 +1051,7 @@ void ChartSector()
     AnsiColor(kObjA[i]);
     sprintf(sz, "%c%c%c%c: ", chObj3(i),
       szObjName[i][3] ? szObjName[i][3] : ' '); PrintSz(sz);
-    r = (rDegMax - planet[i])/10.0;
+    r = GFromO(i);
     sec = (int)r + 1; c[sec]++;
     pls = pluszone[sec];
     cq += pls;
