@@ -1,8 +1,8 @@
 /*
-** Astrolog (Version 5.30) File: extern.h
+** Astrolog (Version 5.40) File: extern.h
 **
 ** IMPORTANT NOTICE: The graphics database and chart display routines
-** used in this program are Copyright (C) 1991-1996 by Walter D. Pullen
+** used in this program are Copyright (C) 1991-1998 by Walter D. Pullen
 ** (Astara@msn.com, http://www.magitech.com/~cruiser1/astrolog.htm).
 ** Permission is granted to freely use and distribute these routines
 ** provided one doesn't sell, restrict, or profit from them in any way.
@@ -32,7 +32,7 @@
 ** Initial programming 8/28,30, 9/10,13,16,20,23, 10/3,6,7, 11/7,10,21/1991.
 ** X Window graphics initially programmed 10/23-29/1991.
 ** PostScript graphics initially programmed 11/29-30/1992.
-** Last code change made 9/22/1996.
+** Last code change made 12/20/1998.
 */
 
 /*
@@ -108,8 +108,7 @@ extern int starname[cStar+1], kObjA[objMax];
 extern byte ignore[objMax], ignore2[objMax], ignorez[4], pluszone[cSector+1];
 extern real rAspAngle[cAspect+1], rAspOrb[cAspect+1], rObjOrb[oNorm+1],
   rObjAdd[oNorm+1];
-extern CONST int rules[cSign+1];
-extern int ruler1[oNorm+1], ruler2[oNorm+1], exalt[oNorm+1],
+extern int ruler1[oNorm+1], ruler2[oNorm+1], exalt[oNorm+1], rules[cSign+1],
   kMainA[9], kRainbowA[8], kElemA[4], kAspA[cAspect+1];
 extern real rObjInf[oNorm+3], rHouseInf[cSign+3], rAspInf[cAspect+1],
   rTransitInf[oNorm+3];
@@ -226,6 +225,7 @@ extern void HouseNull P((void));
 extern void ComputeHouses P((int));
 extern void ComputeStars P((real));
 extern real Decan P((real));
+extern real Navamsa P((real));
 extern void SphToRec P((real, real, real, real *, real *, real *));
 extern void ComputePlacalc P((real));
 extern real CastChart P((bool));
@@ -407,9 +407,10 @@ extern int ikPalette[cColor];
 extern CONST KV rgb[cColor], rgbbmp[cColor];
 extern KI kMainB[9], kRainbowB[8], kElemB[4], kAspB[cAspect+1], kObjB[objMax];
 extern CONST char szObjectFont[oNorm+2], szAspectFont[cAspect+1],
-  *szDrawSign[cSign+2], *szDrawObject[oNorm+5], *szDrawObject2[oNorm+5],
-  *szDrawHouse[cSign+1], *szDrawAspect[cAspect+3], *szDrawAspect2[cAspect+3],
-  *szDrawCh[128-32+1], *szWorldData[62*3], *szDrawConstel[cCnstl+1];
+  *szDrawSign[cSign+2], *szDrawSign2[cSign+2], *szDrawObject[oNorm+5],
+  *szDrawObject2[oNorm+5], *szDrawHouse[cSign+1], *szDrawHouse2[cSign+1],
+  *szDrawAspect[cAspect+3], *szDrawAspect2[cAspect+3], *szDrawCh[128-32+1],
+  *szWorldData[62*3], *szDrawConstel[cCnstl+1];
 
 
 /* From xgeneral.c */
@@ -543,6 +544,7 @@ extern void XChartCalendar P((void));
 extern bool FProper P((int));
 extern void FillSymbolRing P((real *, real));
 extern void FillSymbolLine P((real *));
+extern real PlaceInX P((real));
 extern real HousePlaceInX P((real));
 extern void XChartWheelRelation P((void));
 extern void XChartWheelThreeFour P((void));
