@@ -1,8 +1,8 @@
 /*
-** Astrolog (Version 5.30) File: general.c
+** Astrolog (Version 5.40) File: general.c
 **
 ** IMPORTANT NOTICE: The graphics database and chart display routines
-** used in this program are Copyright (C) 1991-1996 by Walter D. Pullen
+** used in this program are Copyright (C) 1991-1998 by Walter D. Pullen
 ** (Astara@msn.com, http://www.magitech.com/~cruiser1/astrolog.htm).
 ** Permission is granted to freely use and distribute these routines
 ** provided one doesn't sell, restrict, or profit from them in any way.
@@ -32,7 +32,7 @@
 ** Initial programming 8/28,30, 9/10,13,16,20,23, 10/3,6,7, 11/7,10,21/1991.
 ** X Window graphics initially programmed 10/23-29/1991.
 ** PostScript graphics initially programmed 11/29-30/1992.
-** Last code change made 9/22/1996.
+** Last code change made 12/20/1998.
 */
 
 #include "astrolog.h"
@@ -550,7 +550,7 @@ char *sz;
   char szT[cchSzDef];
 
   sprintf(szT, "%s Warning", szAppName);
-  MessageBox((HWND)NULL, sz, szT, MB_ICONSTOP);
+  MessageBox(wi.hwndMain, sz, szT, MB_ICONSTOP);
 #endif
 }
 
@@ -571,7 +571,7 @@ char *sz;
   char szT[cchSzDef];
 
   sprintf(szT, "%s Error", szAppName);
-  MessageBox((HWND)NULL, sz, szT, MB_ICONEXCLAMATION);
+  MessageBox(wi.hwndMain, sz, szT, MB_ICONEXCLAMATION);
 #endif
 }
 
