@@ -1,8 +1,8 @@
 /*
-** Astrolog (Version 5.30) File: wdialog.c
+** Astrolog (Version 5.40) File: wdialog.c
 **
 ** IMPORTANT NOTICE: The graphics database and chart display routines
-** used in this program are Copyright (C) 1991-1996 by Walter D. Pullen
+** used in this program are Copyright (C) 1991-1998 by Walter D. Pullen
 ** (Astara@msn.com, http://www.magitech.com/~cruiser1/astrolog.htm).
 ** Permission is granted to freely use and distribute these routines
 ** provided one doesn't sell, restrict, or profit from them in any way.
@@ -32,7 +32,7 @@
 ** Initial programming 8/28,30, 9/10,13,16,20,23, 10/3,6,7, 11/7,10,21/1991.
 ** X Window graphics initially programmed 10/23-29/1991.
 ** PostScript graphics initially programmed 11/29-30/1992.
-** Last code change made 9/22/1996.
+** Last code change made 12/20/1998.
 */
 
 #include "astrolog.h"
@@ -232,9 +232,15 @@ bool FOutputSettings()
   us.fAnsiChar = fT;
   PrintF("; Default longitude and latitude\n\n");
 
+  sprintf(sz, "-Yz %ld   ", us.lTimeAddition); PrintFSz();
+  PrintF(
+    "; Time minute addition to be used when \"now\" charts are off.\n-n");
+  PrintF(
+    "      ; Uncomment this line to start with the chart for \"now\".\n\n");
+
   sprintf(sz, "%cs      ", ChDashF(us.fSidereal)); PrintFSz();
   PrintF(
-    "; Zodiac selection          [\"_s\" is tropical, \"=s\" is siderial]\n");
+    "; Zodiac selection          [\"_s\" is tropical, \"=s\" is sidereal]\n");
   sprintf(sz, ":s %.0f    ", us.rZodiacOffset); PrintFSz();
   PrintF(
     "; Zodiac offset value       [Change \"0\" to desired offset      ]\n");
@@ -280,13 +286,8 @@ bool FOutputSettings()
   sprintf(sz, "%cY8     ", ChDashF(us.fClip80)); PrintFSz();
   PrintF(
     "; Clip text to end of line  [\"=Y8\" clips, \"_Y8\" doesn't clip   ]\n");
-  sprintf(sz, "-Yz %ld   ", us.lTimeAddition); PrintFSz();
-  PrintF(
-    "; Time minute addition      [Change only if -n charts are off  ]\n\n-n");
-  PrintF(
-    "      ; Uncomment this line to start with the chart for \"now\".\n\n\n");
 
-  PrintF("; DEFAULT RESTRICTIONS:\n\n-YR 1 10     ");
+  PrintF("\n\n; DEFAULT RESTRICTIONS:\n\n-YR 1 10     ");
   for (i = 1; i <= 10; i++) PrintF(SzNumF(ignore[i]));
   PrintF("     ; Planets\n-YR 11 20    ");
   for (i = 11; i <= 20; i++) PrintF(SzNumF(ignore[i]));
@@ -310,11 +311,11 @@ bool FOutputSettings()
     SzNumF(us.fIgnoreSign), SzNumF(us.fIgnoreDir)); PrintFSz();
 
   PrintF("; DEFAULT ASPECT ORBS:\n\n-YAo 1 5    ");
-  for (i = 1; i <= 5; i++) { sprintf(sz, " %.0f", rAspOrb[i]); PrintFSz(); }
+  for (i = 1; i <= 5; i++) { sprintf(sz, " %.1f", rAspOrb[i]); PrintFSz(); }
   PrintF("      ; Major aspects\n-YAo 6 11   ");
-  for (i = 6; i <= 11; i++) { sprintf(sz, " %.0f", rAspOrb[i]); PrintFSz(); }
+  for (i = 6; i <= 11; i++) { sprintf(sz, " %.1f", rAspOrb[i]); PrintFSz(); }
   PrintF("    ; Minor aspects\n-YAo 12 18  ");
-  for (i = 12; i <= 18; i++) { sprintf(sz, " %.0f", rAspOrb[i]); PrintFSz(); }
+  for (i = 12; i <= 18; i++) { sprintf(sz, " %.1f", rAspOrb[i]); PrintFSz(); }
   PrintF("  ; Obscure aspects\n\n");
 
   PrintF("; DEFAULT MAX PLANET ASPECT ORBS:\n\n-YAm 1 10   ");
@@ -327,11 +328,11 @@ bool FOutputSettings()
   for (i = 33; i <= 40; i++) { sprintf(sz, "%4.0f", rObjOrb[i]); PrintFSz(); }
 
   PrintF("\n\n; DEFAULT PLANET ASPECT ORB ADDITIONS:\n\n-YAd 1 10   ");
-  for (i = 1; i <= 10; i++) { sprintf(sz, " %.0f", rObjAdd[i]); PrintFSz(); }
+  for (i = 1; i <= 10; i++) { sprintf(sz, " %.1f", rObjAdd[i]); PrintFSz(); }
   PrintF("\n-YAd 11 20  ");
-  for (i = 11; i <= 20; i++) { sprintf(sz, " %.0f", rObjAdd[i]); PrintFSz(); }
+  for (i = 11; i <= 20; i++) { sprintf(sz, " %.1f", rObjAdd[i]); PrintFSz(); }
   PrintF("\n-YAd 21 32  ");
-  for (i = 21; i <= 32; i++) { sprintf(sz, " %.0f", rObjAdd[i]); PrintFSz(); }
+  for (i = 21; i <= 32; i++) { sprintf(sz, " %.1f", rObjAdd[i]); PrintFSz(); }
 
   PrintF("\n\n\n; DEFAULT INFLUENCES:\n\n-Yj 1 10   ");
   for (i = 1; i <= 10; i++) { sprintf(sz, " %.0f", rObjInf[i]); PrintFSz(); }
@@ -910,6 +911,8 @@ LONG lParam;
   case WM_INITDIALOG:
     SetEditSZOA(hdlg, dcDeDst, dcDeZon, dcDeLon, dcDeLat,
       us.dstDef, us.zonDef, us.lonDef, us.latDef);
+    SetEditN(dcDeCor, (int)us.lTimeAddition);
+    SetCombo(dcDeCor, "60"); SetCombo(dcDeCor, "-60");
     SetFocus(GetDlgItem(hdlg, dcDeDst));
     return fFalse;
 
@@ -919,6 +922,7 @@ LONG lParam;
       GetEdit(dcDeZon, sz); ci.zon = RParseSz(sz, pmZon);
       GetEdit(dcDeLon, sz); ci.lon = RParseSz(sz, pmLon);
       GetEdit(dcDeLat, sz); ci.lat = RParseSz(sz, pmLat);
+      GetEdit(dcDeCor, sz); us.lTimeAddition = atol(sz);
       EnsureR(ci.dst, FValidZon(ci.dst), "daylight");
       EnsureR(ci.zon, FValidZon(ci.zon), "zone");
       EnsureR(ci.lon, FValidLon(ci.lon), "longitude");
@@ -1348,7 +1352,9 @@ LONG lParam;
 
   switch (message) {
   case WM_INITDIALOG:
-    SetEditR(hdlg, deSe_s, us.rZodiacOffset, 6);
+    SetCombo(dcSe_s, "0.0"); SetCombo(dcSe_s, "0.883333");
+    SetCombo(dcSe_s, "2.333333"); SetCombo(dcSe_s, "0.983333");
+    SetEditR(hdlg, dcSe_s, us.rZodiacOffset, 6);
     SetEditN(deSe_A, us.nAsp);
     SetEditN(deSe_x, us.nHarmonic);
     SetEdit(deSe_h, szObjName[us.objCenter]);
@@ -1364,7 +1370,7 @@ LONG lParam;
 
   case WM_COMMAND:
     if (wParam == IDOK) {
-      r1 = GetEditR(hdlg, deSe_s);
+      r1 = GetEditR(hdlg, dcSe_s);
       GetEdit(deSe_A, sz); n2 = NParseSz(sz, pmAspect);
       n3 = GetEditN(deSe_x);
       GetEdit(deSe_h, sz); n4 = NParseSz(sz, pmObject);
