@@ -1,8 +1,8 @@
 /*
-** Astrolog (Version 5.30) File: xcharts0.c
+** Astrolog (Version 5.40) File: xcharts0.c
 **
 ** IMPORTANT NOTICE: The graphics database and chart display routines
-** used in this program are Copyright (C) 1991-1996 by Walter D. Pullen
+** used in this program are Copyright (C) 1991-1998 by Walter D. Pullen
 ** (Astara@msn.com, http://www.magitech.com/~cruiser1/astrolog.htm).
 ** Permission is granted to freely use and distribute these routines
 ** provided one doesn't sell, restrict, or profit from them in any way.
@@ -32,7 +32,7 @@
 ** Initial programming 8/28,30, 9/10,13,16,20,23, 10/3,6,7, 11/7,10,21/1991.
 ** X Window graphics initially programmed 10/23-29/1991.
 ** PostScript graphics initially programmed 11/29-30/1992.
-** Last code change made 9/22/1996.
+** Last code change made 12/20/1998.
 */
 
 #include "astrolog.h"
@@ -91,6 +91,7 @@ void DrawInfo()
   ET et;
   CI ciT;
   int i, y, a, s;
+  real r;
 
 #ifdef INTERPRET
   int tot, abo, lef;
@@ -199,21 +200,32 @@ void DrawInfo()
     sprintf(sz, is.fSeconds ? "%3.3s: " : "%4.4s: ", szObjName[i]);
     DrawPrint(sz, kObjB[i], fTrue);
     y = DrawPrint(SzZodiac(planet[i]), kSignB(SFromZ(planet[i])), fTrue);
-    if (!is.fSeconds && i < starLo && (gs.nScale == 100 ||
-      !gs.fFont || !gi.fFile || gs.fBitmap) && y < gs.yWin-1) {
+    if (!is.fSeconds && i < starLo && gi.nMode != gSector && (gs.nScale ==
+      100 || !gs.fFont || !gi.fFile || gs.fBitmap) && y < gs.yWin-1) {
       s = gi.nScale;
       gi.nScale = gi.nScaleT;
       DrawObject(i, gs.xWin-12*gi.nScaleT, y-(yFont/2-1)*gi.nScaleT);
       gi.nScale = s;
     }
     sprintf(sz, "%c ", ret[i] < 0.0 ? chRet : ' ');
-    s = FThing(i);
-    DrawPrint(sz, gi.kiOn, s);
-    if (s) {
-      is.fSeconds = fFalse;
-      DrawPrint(SzAltitude(planetalt[i]), gi.kiLite, fFalse);
-      is.fSeconds = us.fSeconds;
+    DrawPrint(sz, gi.kiOn, fTrue);
+    if (gi.nMode != gSector || !is.fSeconds) {
+      if (FThing(i)) {
+        is.fSeconds = fFalse;
+        DrawPrint(SzAltitude(planetalt[i]), gi.kiLite, fTrue);
+        is.fSeconds = us.fSeconds;
+      } else
+        DrawPrint("       ", gi.kiOn, fTrue);
     }
+    if (gi.nMode == gSector) {
+      r = GFromO(i); s = (int)r + 1;
+      if (!is.fSeconds)
+        sprintf(sz, " %2d", s);
+      else
+        sprintf(sz, "%6.3f%c", r + 1.0, pluszone[s] ? '+' : '-');
+      DrawPrint(sz, pluszone[s] ? kRainbowB[1] : kMainB[5], fFalse);
+    } else
+      DrawPrint("", gi.kiOn, fFalse);
   }
 
   /* Print star positions. */
@@ -224,7 +236,17 @@ void DrawInfo()
     DrawPrint(sz, kObjB[s], fTrue);
     DrawPrint(SzZodiac(planet[s]), kSignB(SFromZ(planet[s])), fTrue);
     DrawPrint("  ", gi.kiOn, fTrue);
-    DrawPrint(SzAltitude(planetalt[s]), gi.kiLite, fFalse);
+    if (gi.nMode != gSector || !is.fSeconds)
+      DrawPrint(SzAltitude(planetalt[s]), gi.kiLite, fTrue);
+    if (gi.nMode == gSector) {
+      r = GFromO(s); s = (int)r + 1;
+      if (!is.fSeconds)
+        sprintf(sz, " %2d", s);
+      else
+        sprintf(sz, "%6.3f%c", r + 1.0, pluszone[s] ? '+' : '-');
+      DrawPrint(sz, pluszone[s] ? kRainbowB[1] : kMainB[5], fFalse);
+    } else
+      DrawPrint("", gi.kiOn, fFalse);
   }
 
   /* Print element table information. */
