@@ -1,8 +1,8 @@
 /*
-** Astrolog (Version 5.30) File: xcharts2.c
+** Astrolog (Version 5.40) File: xcharts2.c
 **
 ** IMPORTANT NOTICE: The graphics database and chart display routines
-** used in this program are Copyright (C) 1991-1996 by Walter D. Pullen
+** used in this program are Copyright (C) 1991-1998 by Walter D. Pullen
 ** (Astara@msn.com, http://www.magitech.com/~cruiser1/astrolog.htm).
 ** Permission is granted to freely use and distribute these routines
 ** provided one doesn't sell, restrict, or profit from them in any way.
@@ -32,7 +32,7 @@
 ** Initial programming 8/28,30, 9/10,13,16,20,23, 10/3,6,7, 11/7,10,21/1991.
 ** X Window graphics initially programmed 10/23-29/1991.
 ** PostScript graphics initially programmed 11/29-30/1992.
-** Last code change made 9/22/1996.
+** Last code change made 12/20/1998.
 */
 
 #include "astrolog.h"
@@ -171,6 +171,19 @@ real *symbol;
 }
 
 
+/* Given a zodiac position, return the degree on the current wheel chart */
+/* circle where that position falls, rotating based on the Ascendant and */
+/* adding in the opposite direction for Vedic mode wheels.               */
+
+real PlaceInX(deg)
+real deg;
+{
+  if (us.fVedic)
+    deg = -chouse[1]*(gi.nMode != gWheel)*2.0-deg-60.0;
+  return Mod(rDegHalf-deg+gi.rAsc);
+}
+
+
 /* Given a zodiac degree, adjust it if need be to account for the expanding */
 /* and compacting of parts the zodiac that happen when we display a graphic */
 /* wheel chart such that all the houses appear the same size.               */
@@ -204,7 +217,7 @@ void XChartWheelRelation()
     symbol[objMax];
   byte ignoreT[objMax];
   int cx, cy, i, j;
-  real asc, unitx, unity, temp;
+  real unitx, unity, temp;
   CI ciT;
 
   /* Set up variables and temporarily automatically decrease the horizontal */
@@ -214,8 +227,10 @@ void XChartWheelRelation()
     gs.xWin -= xSideT;
   cx = gs.xWin/2 - 1; cy = gs.yWin/2 - 1;
   unitx = (real)cx; unity = (real)cy;
-  asc = gs.objLeft ? cp1.obj[abs(gs.objLeft)]+90*(gs.objLeft < 0) :
+  gi.rAsc = gs.objLeft ? cp1.obj[abs(gs.objLeft)]+rDegQuad*(gs.objLeft < 0) :
     cp1.cusp[1];
+  if (us.fVedic)
+    gi.rAsc = gs.objLeft ? (gs.objLeft < 0 ? 120.0 : -60.0)-gi.rAsc : 0.0;
 
   /* Fill out arrays with the degree of each object, cusp, and sign glyph. */
 
@@ -223,7 +238,7 @@ void XChartWheelRelation()
     for (i = 1; i <= cSign; i++)
       xhouse1[i] = PZ(cp1.cusp[i]);
   } else {
-    asc -= cp1.cusp[1];
+    gi.rAsc -= cp1.cusp[1];
     for (i = 1; i <= cSign; i++)
       xhouse1[i] = PZ(ZFromS(i));
   }
@@ -237,7 +252,7 @@ void XChartWheelRelation()
   /* Go draw the outer sign and house rings. We are drawing only the */
   /* houses of one of the two charts in the relationship, however.   */
 
-  DrawWheel(xsign, xhouse1, cx, cy, unitx, unity, asc,
+  DrawWheel(xsign, xhouse1, cx, cy, unitx, unity, gi.rAsc,
     0.70, 0.74, 0.78, 0.82, 0.885);
 
   /* Draw the outer ring of planets (based on the planets in the chart     */
@@ -330,7 +345,7 @@ void XChartWheelThreeFour()
   real xsign[cSign+1], xhouse1[cSign+1], xplanet1[objMax], xplanet2[objMax],
     symbol[objMax];
   int cx, cy, i, fQuad;
-  real asc, unitx, unity, base;
+  real unitx, unity, base;
   CP cpT;
 
   /* Set up variables and temporarily automatically decrease the horizontal */
@@ -340,8 +355,10 @@ void XChartWheelThreeFour()
     gs.xWin -= xSideT;
   cx = gs.xWin/2 - 1; cy = gs.yWin/2 - 1;
   unitx = (real)cx; unity = (real)cy;
-  asc = gs.objLeft ? cp1.obj[abs(gs.objLeft)]+90*(gs.objLeft < 0) :
+  gi.rAsc = gs.objLeft ? cp1.obj[abs(gs.objLeft)]+rDegQuad*(gs.objLeft < 0) :
     cp1.cusp[1];
+  if (us.fVedic)
+    gi.rAsc = gs.objLeft ? (gs.objLeft < 0 ? 120.0 : -60.0)-gi.rAsc : 0.0;
   fQuad = (us.nRel == rcQuadWheel);
   base = (fQuad ? 0.22 : 0.35);
 
@@ -352,7 +369,7 @@ void XChartWheelThreeFour()
     for (i = 1; i <= cSign; i++)
       xhouse1[i] = PZ(cp1.cusp[i]);
   } else {
-    asc -= cp1.cusp[1];
+    gi.rAsc -= cp1.cusp[1];
     for (i = 1; i <= cSign; i++)
       xhouse1[i] = PZ(ZFromS(i));
   }
@@ -366,7 +383,7 @@ void XChartWheelThreeFour()
   /* Go draw the outer sign and house rings. We are drawing the houses */
   /* of only the outermost ring of the wheel, however.                 */
 
-  DrawWheel(xsign, xhouse1, cx, cy, unitx, unity, asc,
+  DrawWheel(xsign, xhouse1, cx, cy, unitx, unity, gi.rAsc,
     0.745, 0.78, 0.815, 0.84, 0.895);
 
   /* Draw the outer ring of planets (i.e. the one the house cusps reflect). */
@@ -493,6 +510,7 @@ void XChartGridRelation()
     DrawColor(gi.kiLite);
     DrawEdge(0, y*unit, unit, (y+1)*unit);
     DrawEdge(y*unit, 0, (y+1)*unit, unit);
+    DrawEdge(y*unit, y*unit, (y+1)*unit, (y+1)*unit);
     if (j <= cObj) for (x = 0, i = -1; x <= gs.nGridCell; x++) {
       do {
         i++;
