@@ -1,8 +1,8 @@
 /*
-** Astrolog (Version 5.30) File: xdata.c
+** Astrolog (Version 5.40) File: xdata.c
 **
 ** IMPORTANT NOTICE: The graphics database and chart display routines
-** used in this program are Copyright (C) 1991-1996 by Walter D. Pullen
+** used in this program are Copyright (C) 1991-1998 by Walter D. Pullen
 ** (Astara@msn.com, http://www.magitech.com/~cruiser1/astrolog.htm).
 ** Permission is granted to freely use and distribute these routines
 ** provided one doesn't sell, restrict, or profit from them in any way.
@@ -32,7 +32,7 @@
 ** Initial programming 8/28,30, 9/10,13,16,20,23, 10/3,6,7, 11/7,10,21/1991.
 ** X Window graphics initially programmed 10/23-29/1991.
 ** PostScript graphics initially programmed 11/29-30/1992.
-** Last code change made 9/22/1996.
+** Last code change made 12/20/1998.
 */
 
 #include "astrolog.h"
@@ -62,7 +62,7 @@ GS NPTR gs = {
 
 GI NPTR gi = {
   0, fFalse, -1,
-  NULL, 0, NULL, NULL, 0, fFalse,
+  NULL, 0, NULL, NULL, 0, 0.0, fFalse,
   2, 1, 10, kWhite, kBlack, kLtGray, kDkGray, 0, 0, 0, 0, -1, -1
 #ifdef X11
   , NULL, 0, 0, 0, 0, 0, 0, 0, 0
@@ -175,15 +175,30 @@ CONST char * ARR szDrawSign[cSign+2] = {"",
   "BLU3LHBR7GLNL3D6NL3RFBL7ERU3",          /* Gemini      */
   "BGNDHLGDFRNEFR2EREBU3NHDGLHUENRHL2GLG", /* Cancer      */
   "BF4H2UEU2H2L2G2D2FDGH",                 /* Leo         */
-  "BF4BLHNGNHEU5GHND5HGND6HGND6H",         /* Virgo       */
+  "BF4BLHNGNHEU5G2ND3U2HGND6HGND6H",       /* Virgo       */
   "BGNL3HUER2FDGR3BD2L8",                  /* Libra       */
   "BH4FND6EFND6EFD6FREU",                  /* Scorpio     */
   "BG4E3NH2NF2E5NL2D2",                    /* Sagittarius */
-  "BH3NLNUD3FND2EU2ENF2UFERFDGLF2D2G",     /* Capricorn #1 */
+  "BH3BLED4FND2EU2ENF2UFERFDGLF2D2G",      /* Capricorn #1 */
   "BG4EUEDFDEUEDFDEUEBU5GDGUHUGDGUHUGDG",  /* Aquarius    */
   "NL4NR4BH4F2D4G2BR8H2U4E2",              /* Pisces      */
   "BH4RFR2ER3G3D2GDFR2EU2HL3G2DG"};        /* Capricorn #2 */
 
+CONST char * ARR szDrawSign2[cSign+2] = {"",
+  "BD8U7HU3HU2H2L2G2D2F2BR12E2U2H2L2G2D2GD3G",     /* Aries  */
+  "BH6BU2FDFRFNR4GLGDGD4FDFRFR4EREUEU4HUHLHEREUE", /* Taurus */
+  "", /* Gemini */
+  "BG5NRLH2U2E2R2F2D2G2F2R4ER2E3BH6NE2D2F2R2E2U2H2L2H2L4GL2G3", /* Cancer */
+  "", /* Leo   */
+  "", /* Virgo */
+  "", /* Libra */
+  "BH8F2ND12E2F2ND12E2F2D12F2RE2U3NGF", /* Scorpio */
+  "", /* Sagittarius  */
+  "", /* Capricorn #1 */
+  "BG8EUE2UEDFD2FDEUE2UEDFD2FDEUE2UEBU10GDG2DGUHU2HUGDG2DGUHU2HUGDG2DG",
+  "NL8NR8BH8F3DFD6GDG3BR16H3UHU6EUE3", /* Pisces */
+  ""}; /* Capricorn #2 */
+
 CONST char * ARR szDrawObject[oNorm+5] = {
   "ND4NL4NR4U4LGLDGD2FDRFR2ERUEU2HULHL",    /* Earth   */
   "U0BH3DGD2FDRFR2ERUEU2HULHL2GL",          /* Sun     */
@@ -286,6 +301,13 @@ CONST char * ARR szDrawHouse[cSign+1] = {"",
   "BHBUR2DG2D", "NRLU2R2D4L2U2", "NRLU2R2D4L2",
   "BH2NLD4NLRBR2U4R2D4L2", "BH2NLD4NLRBR2RNRU4L", "BH2NLD4NLRBR2NR2U2R2U2L2"};
 
+CONST char * ARR szDrawHouse2[cSign+1] = {"",
+  "BD4NL2NR2U8G2", "BH2BUER2FD2G4DR4", "BH2BUER2FD2GNLFD2GL2H",
+  "BH2BU2D4R3NU4NRD4", "BE2BU2L4D4R3FD2GL2H", "NL2RFD2GL2HU6ER2F",
+  "", "NRLHU2ER2FD2GFD2GL2HU2E", "NR2LHU2ER2FD6GL2H",
+  "BH4NG2D8NL2R2BR5HU6ER2FD6GL2", "BH4NG2D8NL2R2BR4R2NR2U8G2",
+  "BH4NG2D8NL2R2BR4NR4UE4U2HL2G"};
+
 CONST char * ARR szDrawAspect[cAspect+3] = {"",
   "HLG2DF2RE2UHE4",                        /* Conjunction      */
   "BGL2GDFREU2E2U2ERFDGL2",                /* Opposition       */
@@ -318,9 +340,9 @@ CONST char * ARR szDrawAspect2[cAspect+3] = {"",
   "BH8FDFDFDFDFDFDFDFDNL8NR8BUEUEUEUEUEUEUEUE", /* Semisextile */
   "", /* Semisquare       */
   "", /* Sesquiquadrature */
-  "", /* Quintile         */
-  "", /* Biquintile       */
-  "", /* Semiquintile     */
+  "BFF7BU6U4HUH3LHL4GLG3DGD4FDF3RFR4E6", /* Quintile */
+  "", /* Biquintile   */
+  "", /* Semiquintile */
   "", /* Septile      */
   "", /* Novile       */
   "", /* Binovile     */
