@@ -1,8 +1,8 @@
 /*
-** Astrolog (Version 5.30) File: xgeneral.c
+** Astrolog (Version 5.40) File: xgeneral.c
 **
 ** IMPORTANT NOTICE: The graphics database and chart display routines
-** used in this program are Copyright (C) 1991-1996 by Walter D. Pullen
+** used in this program are Copyright (C) 1991-1998 by Walter D. Pullen
 ** (Astara@msn.com, http://www.magitech.com/~cruiser1/astrolog.htm).
 ** Permission is granted to freely use and distribute these routines
 ** provided one doesn't sell, restrict, or profit from them in any way.
@@ -32,7 +32,7 @@
 ** Initial programming 8/28,30, 9/10,13,16,20,23, 10/3,6,7, 11/7,10,21/1991.
 ** X Window graphics initially programmed 10/23-29/1991.
 ** PostScript graphics initially programmed 11/29-30/1992.
-** Last code change made 9/22/1996.
+** Last code change made 12/20/1998.
 */
 
 #include "astrolog.h"
@@ -626,7 +626,7 @@ int x1, y1, x2, y2;
 #endif
 #ifdef WIN
   else
-    Ellipse(wi.hdc, x1, y1, x2, y2);
+    Ellipse(wi.hdc, x1, y1, x2+1, y2+1);
 #endif
 #ifdef MSG
   else
@@ -731,7 +731,13 @@ int i, x, y;
 #endif
   if (i == sCap && gs.nGlyphs/1000 > 1)
     i = cSign+1;
-  DrawTurtle(szDrawSign[i], x, y);
+  if ((gi.nScale & 1) || !szDrawSign2[i][0])
+    DrawTurtle(szDrawSign[i], x, y);
+  else {
+    gi.nScale >>= 1;
+    DrawTurtle(szDrawSign2[i], x, y);  /* Special hi-res sign glyphs. */
+    gi.nScale <<= 1;
+  }
 }
 
 
@@ -759,7 +765,13 @@ int i, x, y;
     return;
   }
 #endif
-  DrawTurtle(szDrawHouse[i], x, y);
+  if ((gi.nScale & 1) || !szDrawHouse2[i][0])
+    DrawTurtle(szDrawHouse[i], x, y);
+  else {
+    gi.nScale >>= 1;
+    DrawTurtle(szDrawHouse2[i], x, y);  /* Special hi-res house numbers. */
+    gi.nScale <<= 1;
+  }
 }
 
 
