@@ -1,8 +1,8 @@
 /*
-** Astrolog (Version 5.30) File: xscreen.c
+** Astrolog (Version 5.40) File: xscreen.c
 **
 ** IMPORTANT NOTICE: The graphics database and chart display routines
-** used in this program are Copyright (C) 1991-1996 by Walter D. Pullen
+** used in this program are Copyright (C) 1991-1998 by Walter D. Pullen
 ** (Astara@msn.com, http://www.magitech.com/~cruiser1/astrolog.htm).
 ** Permission is granted to freely use and distribute these routines
 ** provided one doesn't sell, restrict, or profit from them in any way.
@@ -32,7 +32,7 @@
 ** Initial programming 8/28,30, 9/10,13,16,20,23, 10/3,6,7, 11/7,10,21/1991.
 ** X Window graphics initially programmed 10/23-29/1991.
 ** PostScript graphics initially programmed 11/29-30/1992.
-** Last code change made 9/22/1996.
+** Last code change made 12/20/1998.
 */
 
 #include "astrolog.h"
@@ -315,7 +315,7 @@ void BeginX()
   gi.rcBounds.top = 20 + GetMBarHeight();
   gi.rcBounds.right = gi.rcBounds.left + gs.xWin;
   gi.rcBounds.bottom = gi.rcBounds.top + gs.yWin;
-  gi.wpAst = NewCWindow(0L, &gi.rcBounds, "\pAstrolog 5.30", true,
+  gi.wpAst = NewCWindow(0L, &gi.rcBounds, "\pAstrolog 5.40", true,
     noGrowDocProc, (WindowPtr)-1L, true, 0);
   SetPort(gi.wpAst);
   InitColorsX();
@@ -1025,6 +1025,14 @@ LSwitch:
             not(us.fDecan);
             fCast = fTrue;
             break;
+          case 'z':
+            not(us.fVedic);
+            fRedraw = fTrue;
+            break;
+          case 'y':
+            not(us.fNavamsa);
+            fCast = fTrue;
+            break;
           case '+':
             Animate(gs.nAnim, abs(dir));
             fCast = fTrue;
